@@ -32,6 +32,6 @@ __all__ = (
 ErrorCauseType = Literal["IAM_PERMISSION_REVOKED", "KINESIS_STREAM_NOT_FOUND"]
 ExportStatusType = Literal["CANCELLED", "COMPLETED", "IN_PROGRESS"]
 LedgerStateType = Literal["ACTIVE", "CREATING", "DELETED", "DELETING"]
-PermissionsModeType = Literal["ALLOW_ALL"]
+PermissionsModeType = Literal["ALLOW_ALL", "STANDARD"]
 S3ObjectEncryptionTypeType = Literal["NO_ENCRYPTION", "SSE_KMS", "SSE_S3"]
 StreamStatusType = Literal["ACTIVE", "CANCELED", "COMPLETED", "FAILED", "IMPAIRED"]
